.. _spkg_urllib3:

urllib3: HTTP library with thread-safe connection pooling, file post, and more
==============================================================================

Description
-----------

HTTP library with thread-safe connection pooling, file post, and more

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/urllib3/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.6.3

version_requirements.txt::

    urllib3

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install urllib3

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i urllib3

.. tab:: Arch Linux:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S python-urllib3

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install urllib3

.. tab:: Debian/Ubuntu:

   .. CODE-BLOCK:: bash

       $ sudo apt-get install python3-urllib3

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-urllib3

.. tab:: FreeBSD:

   .. CODE-BLOCK:: bash

       $ sudo pkg install net/py-urllib3

.. tab:: Gentoo Linux:

   .. CODE-BLOCK:: bash

       $ sudo emerge dev-python/urllib3

.. tab:: mingw-w64:

   .. CODE-BLOCK:: bash

       $ sudo pacman -S ${MINGW_PACKAGE_PREFIX}-python-urllib3

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3-urllib3

.. tab:: Void Linux:

   .. CODE-BLOCK:: bash

       $ sudo xbps-install python3-urllib3


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
